@@ -37,10 +37,14 @@ class ModelViewset(DynamicModelViewSet):
     def perform_create(self, serializer):
         if 'user_modified' in serializer.fields:
             serializer.save(user_created=self.request.user,user_modified=self.request.user)
+        else:
+            serializer.save()
 
     def perform_update(self,serializer):
         if 'user_modified' in serializer.fields:
             serializer.save(user_modified=self.request.user)
+        else:
+            serializer.save()
 
     @action(detail=False)
     def excel(self, request, *args, **kwargs):
